/* mainProgram.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef MAINPROGRAM_H
#define MAINPROGRAM_H

// This is a base class for any Paloma utility program that doesn't
// attach to a database and doesn't use Gtk.  It provides some default
// command-line options and does some initialization.  See
// DatabaseProgram and GtkProgram for more specialized base classes.

#include <string>
#include <vector>

class MainProgram {
public:
  typedef vector<string> Args;

  MainProgram(const string &program_name);
  void define_opt(const string &opt, bool takes_arg);

  virtual void command_line(int argc, char *argv[]);
  virtual void init();
  virtual void run();

protected:
  virtual void handle_opts(const string &opt, const string &arg);
  virtual void handle_args(const Args &args);

  virtual void help();
  virtual void usage();
  virtual void describe_options();
  virtual void describe_args();

  class Opt {
  public:
    string _opt;
    bool _takes_arg;
  };

  typedef vector<Opt> Opts;
  Opts _opts;

  string _program_name;
};

#endif
