/* formComboBoxDef.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "formComboBoxDef.h"
#include "dataCell.h"
#include "database.h"

FormComboItemDef::ItemMap FormComboItemDef::_items;
FormComboBoxDef::BoxMap FormComboBoxDef::_boxes;


FormComboItemDef &FormComboItemDef::
find_item(int combo_item_id, const string &label) {
  ItemMap::iterator imi = _items.find(combo_item_id);
  if (imi != _items.end()) {
    return (*imi).second;
  }

  imi = _items.insert(ItemMap::value_type
		      (combo_item_id, 
		       FormComboItemDef(combo_item_id, label))).first;
  return (*imi).second;
}

FormComboItemDef::
FormComboItemDef(int combo_item_id, const string &label) :
  _combo_item_id(combo_item_id),
  _label(label)
{
}

FormComboBoxDef &FormComboBoxDef::
find_box(int combo_box_id) {
  BoxMap::iterator imi = _boxes.find(combo_box_id);
  if (imi != _boxes.end()) {
    return (*imi).second;
  }

  imi = _boxes.insert(BoxMap::value_type
		      (combo_box_id, 
		       FormComboBoxDef(combo_box_id))).first;
  return (*imi).second;
}

LabeledCombo *FormComboBoxDef::
make_widget(const string &widget_label) const {
  LabeledCombo *combo = new LabeledCombo(widget_label);
  G_List_string string_items;

  Items::const_iterator ii;
  for (ii = _items.begin(); ii != _items.end(); ++ii) {
    string_items.append((char *)(*ii)->_label.c_str());
  }

  combo->_widget.set_popdown_strings(string_items);
  combo->_widget.set_value_in_list(true, true);
  return combo;
}

int FormComboBoxDef::
get_id(const string &combo_item_label) const {
  Items::const_iterator ii;
  for (ii = _items.begin(); ii != _items.end(); ++ii) {
    if ((*ii)->_label == combo_item_label) {
      return (*ii)->_combo_item_id;
    }
  }

  return -1;
}

string FormComboBoxDef::
get_label(int combo_item_id) const {
  Items::const_iterator ii;
  for (ii = _items.begin(); ii != _items.end(); ++ii) {
    if ((*ii)->_combo_item_id == combo_item_id) {
      return (*ii)->_label;
    }
  }

  return string();
}

FormComboBoxDef::
FormComboBoxDef(int combo_box_id) :
  _combo_box_id(combo_box_id)
{
  QueryResult qr = music_db->sql_command
    ("SELECT description FROM combo_boxes WHERE combo_box_id=" +
     DataCell(_combo_box_id));

  assert(qr.get_num_rows() != 0);

  _description = qr.get_cell(0, 0).get_string();

  qr = music_db->sql_command
    ("SELECT combo_fields.combo_item_id, combo_items.label"
     " FROM combo_fields, combo_items"
     " WHERE combo_fields.combo_item_id=combo_items.combo_item_id"
     " AND combo_fields.combo_box_id=" + DataCell(_combo_box_id) +
     " ORDER BY combo_fields.sequence");

  int num_rows = qr.get_num_rows();
  for (int i = 0; i < num_rows; i++) {
    int combo_item_id = qr.get_cell(i, 0).get_int();
    string label = qr.get_cell(i, 1).get_string();
    _items.push_back(&FormComboItemDef::find_item(combo_item_id, label));
  }
}
