/* palomaDialog.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "palomaDialog.h"
#include "palomaWindow.h"

PalomaDialog::
PalomaDialog(const Dataset &data) : _data(data) {
  _destroyed = false;
}

PalomaDialog::
~PalomaDialog() {
  // We must hide the window before we destruct, or it won't disappear
  // from the screen.  Strange.  But we also don't want to try to hide
  // the window if we're destructing because of a window_destroyed
  // event, so we check our little flag.
  if (!_destroyed) {
    hide();
  }

  // Delete all of the dialogs we own.
  Dialogs::iterator di;
  for (di = _child_dialogs.begin(); di != _child_dialogs.end(); ++di) {
    delete (*di);
  }

  deleted();
}

void PalomaDialog::
record_db() {
  // The abstract PalomaDialog class does nothing when asked to record
  // its data.  Each concrete type of PalomaDialog saves out its own
  // kind of data.
}

const Dataset &PalomaDialog::
get_data() const {
  return _data;
}

void PalomaDialog::
setup() {
  connect_to_method(destroy, this, &window_destroyed);
  show();
  PalomaWindow::setup_icon_for_window(this, _icon_pixmap, _icon_window);
}

void PalomaDialog::
add_child_dialog(PalomaDialog *dialog) {
  connect_to_method(dialog->deleted, this, &got_child_dialog_delete, dialog);
  _child_dialogs.insert(dialog);
}

void PalomaDialog::
got_child_dialog_delete(PalomaDialog *dialog) {
  _child_dialogs.erase(dialog);
}

void PalomaDialog::
window_destroyed() {
  _destroyed = true;
  delete_self();
}
