/* tableDataProxy.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef TABLEDATAPROXY_H
#define TABLEDATAPROXY_H

#include "tableInfo.h"
#include "referenceCount.h"

#include <iostream.h>

class TableData;
class DataCell;

class TableDataProxy : public ReferenceCountProxy {
public:
  TableDataProxy();
  TableDataProxy(TableData *ptr);
  TableDataProxy(TableID table_id);
  TableDataProxy(TableID table_id, int primary_key_value);
  TableDataProxy(const TableDataProxy &copy);
  TableDataProxy &operator = (const TableDataProxy &copy);

  bool operator == (const TableDataProxy &other) const;
  bool has_table() const;

  TableID get_table_id() const;
  bool has_fields() const;

  void set_primary_key(int primary_key_value, bool new_data = true);
  int get_primary_key() const;
  bool is_new_data() const;
  int record_db();
  int record_db(int primary_key_value);

  DataCell &operator [] (int field_id);
  const DataCell operator [] (int field_id) const;

  void set_db_value(int field_id, const DataCell &value);
  const DataCell get_db_value(int field_id) const;

  void output(ostream &out) const;

protected:
  TableData *get_mod_ptr();
  const TableData *get_const_ptr() const;

  TableID _table_id;
};

inline ostream &operator << (ostream &out, const TableDataProxy &proxy) {
  proxy.output(out);
  return out;
}

#endif
